summaryrefslogtreecommitdiffstats
path: root/devtools/server/connectors/worker-connector.js
diff options
context:
space:
mode:
Diffstat (limited to 'devtools/server/connectors/worker-connector.js')
-rw-r--r--devtools/server/connectors/worker-connector.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/devtools/server/connectors/worker-connector.js b/devtools/server/connectors/worker-connector.js
index 90d55d7a69..dc72993d7a 100644
--- a/devtools/server/connectors/worker-connector.js
+++ b/devtools/server/connectors/worker-connector.js
@@ -46,9 +46,9 @@ function connectToWorker(connection, dbg, forwardingPrefix, options) {
onMessage: message => {
message = JSON.parse(message);
if (message.type !== "rpc") {
- if (message.type == "worker-thread-attached") {
- // The thread actor has finished attaching and can hit installed
- // breakpoints. Allow content to begin executing in the worker.
+ if (message.type == "session-data-processed") {
+ // The thread actor has finished processing session data, including breakpoints.
+ // Allow content to begin executing in the worker and possibly hit early breakpoints.
dbg.setDebuggerReady(true);
}
return;